@@ -44,7 +44,9 @@ else:
 # 3.4            | pip      | 19.1.1       |
 
 # Things that change more often go here.
-copyright = """Copyright (C) 2013, 2015-2021, 2023 Rocky Bernstein <rocky@gnu.org>."""
+copyright = (
+    """Copyright (C) 2013, 2015-2021, 2023-2024 Rocky Bernstein <rocky@gnu.org>."""
+)
 classifiers = [
     "Development Status :: 5 - Production/Stable",
     "Environment :: Console",
@@ -63,6 +65,8 @@ classifiers = [
     "Programming Language :: Python :: 3.8",
     "Programming Language :: Python :: 3.9",
     "Programming Language :: Python :: 3.10",
+    "Programming Language :: Python :: 3.11",
+    "Programming Language :: Python :: 3.12",
     "Programming Language :: Python :: Implementation :: PyPy",
 ]
 
@@ -80,15 +84,17 @@ entry_points = {
 ftp_url = None
 install_requires = [
     "columnize >= 0.3.10",
-    "nose>=1.0.0, <= 1.3.7",
     "pyficache >= 2.3.0",
-    "xdis >= 6.0.3,<6.1.0",
+    "xdis >= 6.0.3,<6.2.0",
     "pygments %s" % pygments_version,
     "spark_parser >= 1.8.9, <1.9.0",
     "tracer >= 0.3.2",
     "term-background >= 1.0.1",
-    decompiler,
 ]
+
+if decompiler is not None:
+    install_requires.append(decompiler)
+
 license = "GPL3"
 mailing_list = "python-debugger@googlegroups.com"
 modname = "trepan3k"
