@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
-#   Copyright (C) 2008-2010, 2013-2016, 2020 2023 Rocky Bernstein
-#   <rocky@gnu.org>
+#   Copyright (C) 2008-2010, 2013-2016, 2020 2023-2024
+#   Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -29,15 +29,18 @@ import os
 import os.path as osp
 import sys
 import threading
+from typing import Any
 
 # External packages
 import pyficache
 import tracer
 
+import trepan
 import trepan.clifns as Mclifns
 
 # Our local modules
-from trepan.lib import breakpoint, default, stack as Mstack
+from trepan.lib import breakpoint, default
+from trepan.lib.stack import count_frames
 from trepan.misc import option_set
 from trepan.processor import cmdproc as Mcmdproc, trace as Mtrace
 
@@ -60,9 +63,8 @@ class TrepanCore(object):
         See also `start' and `stop'.
         """
 
-        import trepan.bwprocessor as Mbwproc
-
-        get_option = lambda key: option_set(opts, key, self.DEFAULT_INIT_OPTS)
+        def get_option(key: str) -> Any:
+            return option_set(opts, key, self.DEFAULT_INIT_OPTS)
 
         self.bpmgr = breakpoint.BreakpointManager()
         self.current_bp = None
@@ -92,7 +94,7 @@ class TrepanCore(object):
         if not self.processor:
             self.processor = Mcmdproc.CommandProcessor(self, opts=proc_opts)
         elif self.processor == "bullwinkle":
-            self.processor = Mbwproc.BWProcessor(self, opts=proc_opts)
+            self.processor = trepan.bwprocessor.BWProcessor(self, opts=proc_opts)
             pass
         # What events are considered in stepping. Note: 'None' means *all*.
         self.step_events = None
@@ -179,7 +181,9 @@ class TrepanCore(object):
                 pass
             canonic = osp.realpath(osp.normcase(canonic))
             self.filename_cache[filename] = canonic
-        canonic = pyficache.unmap_file(canonic)
+        if pyficache is not None:
+            # removing logging can null out pyficache
+            canonic = pyficache.unmap_file(canonic)
 
         return canonic
 
@@ -229,7 +233,9 @@ class TrepanCore(object):
         #    sys.settrace(self._trace_dispatch)
         try:
             self.trace_hook_suspend = True
-            get_option = lambda key: option_set(opts, key, default.START_OPTS)
+
+            def get_option(key: str) -> Any:
+                return option_set(opts, key, default.START_OPTS)
 
             add_hook_opts = get_option("add_hook_opts")
 
@@ -256,7 +262,10 @@ class TrepanCore(object):
         #    sys.settrace(None)
         try:
             self.trace_hook_suspend = True
-            get_option = lambda key: option_set(options, key, default.STOP_OPTS)
+
+            def get_option(key: str) -> Any:
+                return option_set(options, key, default.STOP_OPTS)
+
             args = [self.trace_dispatch]
             remove = get_option("remove")
             if remove:
@@ -288,7 +297,7 @@ class TrepanCore(object):
                     else:
                         msg = ""
                         pass
-                    self.stop_reason = "at %scall breakpoint %d" % (msg, bp.number)
+                    self.stop_reason = f"at {msg}call breakpoint {bp.number}"
                     self.event = "brkpt"
                     return True
                 pass
@@ -303,7 +312,7 @@ class TrepanCore(object):
                 else:
                     msg = ""
                     pass
-                self.stop_reason = "at %sline breakpoint %d" % (msg, bp.number)
+                self.stop_reason = f"at {msg}line breakpoint {bp.number}"
                 self.event = "brkpt"
                 return True
             else:
@@ -354,7 +363,7 @@ class TrepanCore(object):
         if self.stop_level is not None:
             if frame and frame != self.last_frame:
                 # Recompute stack_depth
-                self.last_level = Mstack.count_frames(frame)
+                self.last_level = count_frames(frame)
                 self.last_frame = frame
                 pass
             if self.last_level > self.stop_level:
@@ -389,7 +398,7 @@ class TrepanCore(object):
     def set_next(self, frame, step_ignore=0, step_events=None):
         "Sets to stop on the next event that happens in frame 'frame'."
         self.step_events = None  # Consider all events
-        self.stop_level = Mstack.count_frames(frame)
+        self.stop_level = count_frames(frame)
         self.last_level = self.stop_level
         self.last_frame = frame
         self.stop_on_finish = False
