@@ -6,7 +6,9 @@
 import inspect
 import sys
 import types
+from typing import Callable
 
+from pygments.token import Comment
 from xdis import (
     IS_PYPY,
     Bytecode,
@@ -15,12 +17,12 @@ from xdis import (
     get_instructions_bytes,
     get_opcode,
 )
+from xdis.instruction import Instruction
 from xdis.std import distb
 from xdis.version_info import PYTHON_VERSION_TRIPLE
 
 from trepan.lib.format import (
     Arrow,
-    Comment,
     Details,
     Hex,
     Integer,
@@ -52,8 +54,8 @@ def _try_compile(source, name):
 
 
 def dis(
-    msg,
-    msg_nocr,
+    msg: Callable,
+    msg_nocr: Callable,
     section,
     errmsg,
     x=None,
@@ -93,21 +95,21 @@ def dis(
     if hasattr(types, "InstanceType") and isinstance(x, types.InstanceType):
         x = x.__class__
     if inspect.ismethod(x):
-        section("Disassembly of %s: %s" % (x, mess))
+        section(f"Disassembly of {x}: {mess}")
         sectioned = True
         x = x.__func__.__code__
     elif inspect.isfunction(x) or inspect.isgeneratorfunction(x):
-        section("Disassembly of %s: %s" % (x, mess))
+        section(f"Disassembly of {x}: {mess}")
         x = x.__code__
         sectioned = True
     elif inspect.isgenerator(x):
-        section("Disassembly of %s: %s" % (x, mess))
+        section(f"Disassembly of {x}: {mess}")
         frame = x.gi_frame
         lasti = frame.f_last_i
         x = x.gi_code
         sectioned = True
     elif inspect.isframe(x):
-        section("Disassembly of %s: %s" % (x, mess))
+        section(f"Disassembly of {x}: {mess}")
         sectioned = True
         if hasattr(x, "f_lasti"):
             lasti = x.f_lasti
@@ -129,7 +131,7 @@ def dis(
         for name, x1 in items:
             if isinstance(x1, _have_code):
                 if not sectioned:
-                    section("Disassembly of %s: " % x)
+                    section(f"Disassembly of {x}: ")
                 try:
                     dis(
                         msg,
@@ -152,11 +154,10 @@ def dis(
         pass
     elif hasattr(x, "co_code"):  # Code object
         if not sectioned:
-            section("Disassembly of %s: " % x)
+            section(f"Disassembly of {x}: ")
         return disassemble(
             msg,
             msg_nocr,
-            section,
             x,
             lasti=lasti,
             start_line=start_line,
@@ -174,17 +175,16 @@ def dis(
             x,
         )
     else:
-        errmsg("Don't know how to disassemble %s objects." % type(x).__name__)
+        errmsg(f"Don't know how to disassemble {type(x).__name__} objects.")
     return None, None
 
 
 def disassemble(
-    msg,
-    msg_nocr,
-    section,
+    msg: Callable,
+    msg_nocr: Callable,
     co,
-    lasti=-1,
-    start_line=-1,
+    lasti: int = -1,
+    start_line: int = -1,
     end_line=None,
     relative_pos=False,
     highlight="light",
@@ -225,8 +225,8 @@ opc = get_opcode(PYTHON_VERSION_TRIPLE, IS_PYPY)
 
 
 def disassemble_bytes(
-    orig_msg,
-    orig_msg_nocr,
+    orig_msg: Callable,
+    orig_msg_nocr: Callable,
     code,
     lasti=-1,
     cur_line=0,
@@ -257,7 +257,9 @@ def disassemble_bytes(
 
     labels = findlabels(code, opc)
 
-    null_print = lambda x: None
+    def null_print(x):
+        return None
+
     if start_line > cur_line:
         msg_nocr = null_print
         msg = null_print
@@ -273,6 +275,14 @@ def disassemble_bytes(
         if end_offset and offset > end_offset:
             break
 
+        # Python 3.11 introduces "CACHE" and the convention seems to be
+        # to not print these normally.
+        if instr.opname == "CACHE" and asm_format not in (
+            "extended_bytes",
+            "bytes",
+        ):
+            continue
+
         # Column: Source code line number
         if instr.starts_line:
             if offset:
@@ -319,7 +329,7 @@ def disassemble_bytes(
         # Column: Instruction bytes
         if asm_format in ("extended-bytes", "bytes"):
             msg_nocr(format_token(Symbol, "|", highlight=highlight))
-            msg_nocr(format_token(Hex, "%02x" % instr.opcode, highlight=highlight))
+            msg_nocr(format_token(Hex, f"{instr.opcode:02x}", highlight=highlight))
             if instr.inst_size == 1:
                 # Not 3.6 or later
                 msg_nocr(" " * (2 * 3))
@@ -329,7 +339,7 @@ def disassemble_bytes(
                 if instr.has_arg:
                     msg_nocr(
                         format_token(
-                            Hex, "%02x" % (instr.arg % 256), highlight=highlight
+                            Hex, f"{instr.arg % 256:02x}", highlight=highlight
                         )
                     )
                 else:
@@ -337,9 +347,9 @@ def disassemble_bytes(
             elif instr.inst_size == 3:
                 # Not 3.6 or later
                 opbyte, operand_byte = divmod(instr.arg, 256)
-                msg_nocr(format_token(Hex, "%02x" % opbyte, highlight=highlight))
+                msg_nocr(format_token(Hex, f"{opbyte:02x}", highlight=highlight))
                 msg_nocr(" ")
-                msg_nocr(format_token(Hex, "%02x" % operand_byte, highlight=highlight))
+                msg_nocr(format_token(Hex, f"{operand_byte:02x}", highlight=highlight))
 
             msg_nocr(format_token(Symbol, "|", highlight=highlight))
             msg_nocr(" ")
@@ -359,10 +369,17 @@ def disassemble_bytes(
                     hasattr(opc, "opcode_extended_fmt")
                     and opc.opname[op] in opc.opcode_extended_fmt
                 ):
-                    new_repr = f"""["{opc.opcode_extended_fmt[opc.opname[op]](
+                    tos_str, start_offset = opc.opcode_extended_fmt[opc.opname[op]](
                         opc, list(reversed(instructions))
-                    )}"] {instr.arg}"""
-                    argrepr = new_repr
+                    )
+                    if start_offset is not None:
+                        argrepr = tos_str
+                        new_instruction = list(instructions[-1])
+                        new_instruction[-2] = tos_str
+                        new_instruction[-1] = start_offset
+                        del instructions[-1]
+                        instructions.append(Instruction(*new_instruction))
+
                 pass
         elif asm_format in ("extended", "extended-bytes"):
             # Note: instr.arg is also None
@@ -385,9 +402,7 @@ def disassemble_bytes(
             pass
         else:
             # Column: Opcode argument details
-            msg_nocr(format_token(Symbol, "(", highlight=highlight))
-            msg_nocr(format_token(Details, argrepr, highlight=highlight))
-            msg(format_token(Symbol, ")", highlight=highlight))
+            msg(format_token(Details, argrepr, highlight=highlight))
         pass
 
     return code, offset
@@ -400,18 +415,22 @@ if __name__ == "__main__":
         print(msg_str)
         return
 
+
     def msg_nocr(msg_str):
         sys.stdout.write(msg_str)
         return
 
+
     def errmsg(msg_str):
         msg("*** " + msg_str)
         return
 
+
     def section(msg_str):
         msg("=== " + msg_str + " ===")
         return
 
+
     curframe = inspect.currentframe()
     # dis(msg, msg_nocr, errmsg, section, curframe,
     #     start_line=10, end_line=40, highlight='dark')
@@ -420,7 +439,8 @@ if __name__ == "__main__":
     # dis(msg, msg_nocr, errmsg, section, curframe,
     #     start_offset=10, end_offset=20, highlight='dark')
     print("-" * 40)
-    for asm_format in ("std", "extended", "bytes", "extended-bytes"):
+    # for asm_format in ("std", "extended", "bytes", "extended-bytes"):
+    for asm_format in ("extended", "bytes", "extended-bytes"):
         print("Format is", asm_format)
         dis(msg, msg_nocr, section, errmsg, disassemble, asm_format=asm_format)
         print("=" * 30)
