@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-#   Copyright (C) 2013, 2015, 2017, 2019, 2020, 2023
+#   Copyright (C) 2013, 2015, 2017, 2019, 2020, 2023-2024
 #   Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -38,16 +38,46 @@ from pygments.token import (
     String,
     Token,
 )
-from pygments.util import get_choice_opt
+
+from trepan.lib.default import DEBUGGER_SETTINGS
 
 # Set up my own color scheme with some additional definitions.
 color_scheme = TERMINAL_COLORS.copy()
+# color_scheme = {
+#     Token:              ('',            ''),
+#     Comment:            ('gray',   'brightblack'),
+#     Comment.Preproc:    ('cyan',        'brightcyan'),
+#     Keyword:            ('blue',    'brightblue'),
+#     Keyword.Type:       ('cyan',        'brightcyan'),
+#     Operator.Word:      ('magenta',      'brightmagenta'),
+#     Name.Builtin:       ('cyan',        'brightcyan'),
+#     Name.Function:      ('green',   'brightgreen'),
+#     Name.Namespace:     ('_cyan_',      '_brightcyan_'),
+#     Name.Class:         ('_green_', '_brightgreen_'),
+#     Name.Exception:     ('cyan',        'brightcyan'),
+#     Name.Decorator:     ('brightblack',    'gray'),
+#     Name.Variable:      ('red',     'brightred'),
+#     Name.Constant:      ('red',     'brightred'),
+#     Name.Attribute:     ('cyan',        'brightcyan'),
+#     Name.Tag:           ('brightblue',        'brightblue'),
+#     String:             ('gray',       'yellow'),
+#     Number:             ('blue',    'brightblue'),
+#     Generic.Deleted:    ('brightred',        'brightred'),
+#     Generic.Inserted:   ('green',  'brightgreen'),
+#     Generic.Heading:    ('**',         '**'),
+#     Generic.Subheading: ('*magenta*',   '*brightmagenta*'),
+#     Generic.Prompt:     ('**',         '**'),
+#     Generic.Error:      ('brightred',        'brightred'),
+# }
+
+
 color_scheme[Generic.Strong] = ("*black*", "*white*")
 color_scheme[Name.Variable] = ("_black_", "_white_")
 
 color_scheme[Generic.Strong] = ("*black*", "*white*")
 color_scheme[Name.Variable] = ("_black_", "_white_")
-color_scheme[Generic.Emph] = color_scheme[Comment.Preproc]
+color_scheme[Generic.Emph] = ("blue", "brightcyan")
+color_scheme[Token.Literal.String] = ("magenta", "yellow")
 
 # Assume pygments has fixed up the horrible atom colors
 # FIXME: change some horrible colors under atom dark
@@ -65,11 +95,13 @@ pyficache.light_terminal_formatter.colorscheme = color_scheme
 def format_token(ttype, token, colorscheme=color_scheme, highlight="light"):
     if "plain" == highlight:
         return token
-    dark_bg = "dark" == highlight
-
+    is_dark_bg = 1 if DEBUGGER_SETTINGS["highlight"] == "dark" else 0
     color = colorscheme.get(ttype)
     if color:
-        color = color[dark_bg]
+        color = color[is_dark_bg]
+        if isinstance(token, tuple):
+            # have (token, start offset)
+            token = token[0]
         return ansiformat(color, token)
         pass
     return token
@@ -123,7 +155,7 @@ class RstFilter(Filter):
                 # That is remove:
                 # Header
                 # ------ <- remove this line
-                if last_was_heading_title and re.match(r"^(?:[=]|[-])+$", value):
+                if last_was_heading_title and re.match(r"^(?:=|-)+$", value):
                     value = ""
                     last_was_heading_title = ""
                 else:
@@ -157,15 +189,14 @@ class RSTTerminalFormatter(Formatter):
         A dictionary mapping token types to (lightbg, darkbg) color names or
         ``None`` (default: ``None`` = use builtin colorscheme).
     """
+
     name = "Terminal"
     aliases = ["terminal", "console"]
     filenames = []
 
     def __init__(self, **options):
         Formatter.__init__(self, **options)
-        self.darkbg = (
-            get_choice_opt(options, "bg", ["light", "dark"], "light") != "dark"
-        )
+        self.is_dark_bg = 1 if DEBUGGER_SETTINGS["highlight"] == "dark" else 0
         self.colorscheme = options.get("colorscheme", None) or color_scheme
         self.width = options.get("width", 80)
         self.verbatim = False
@@ -200,7 +231,7 @@ class RSTTerminalFormatter(Formatter):
         # color
         if self.__class__ != MonoRSTTerminalFormatter:
             cs = self.colorscheme.get(Verbatim)
-            color = cs[self.darkbg]
+            color = cs[self.is_dark_bg]
         else:
             color = None
             pass
@@ -223,7 +254,7 @@ class RSTTerminalFormatter(Formatter):
         # print '%r' % text
         # from trepan.api import debug
         # if u' or ' == text: debug()
-        if text == "::" and ttype == Token.Literal.String.Escape:
+        if text == "::" and ttype == Token.Literal.String:
             self.verbatim = "colon-verbatim"
             return
         elif (
@@ -315,7 +346,7 @@ class RSTTerminalFormatter(Formatter):
                 color = self.colorscheme.get(resolved_type)
                 pass
             if color:
-                color = color[self.darkbg]
+                color = color[self.is_dark_bg]
             self.reflow_text(text, ttype, color)
             pass
         return
@@ -327,10 +358,10 @@ class MonoRSTTerminalFormatter(RSTTerminalFormatter):
     def format_unencoded(self, tokensource, outfile):
         for ttype, text in tokensource:
             if ttype is Token.Name.Variable:
-                text = '"%s"' % text
+                text = f'"{text}"'
                 pass
             elif ttype is Token.Generic.Emph:
-                text = "*%s*" % text
+                text = f"*{text}*"
                 pass
             elif ttype is Token.Generic.Strong:
                 text = text.upper()
@@ -346,11 +377,10 @@ class MonoTerminalFormatter(TerminalFormatter):
     def format_unencoded(self, tokensource, outfile):
         for ttype, text in tokensource:
             if ttype is Token.Name.Variable:
-                text = '"%s"' % text
+                text = f'"{text}"'
                 pass
             elif ttype is Token.Generic.Emph:
-                type
-                text = "*%s*" % text
+                text = f"*{text}*"
                 pass
             elif ttype is Token.Generic.Strong:
                 text = text.upper()
