@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2013, 2015, 2017-2018, 2020-2021 Rocky Bernstein <rocky@gnu.org>
+#
+#   Copyright (C) 2013, 2015, 2017-2018, 2020-2021, 2023 Rocky
+#   Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -17,9 +19,10 @@
 counts, to parse a string for an integer, or check a string for an
 on/off setting value.
 """
-import os, sys, tempfile
-import pyficache
-from xdis import IS_PYPY, PYTHON_VERSION
+import sys
+import tempfile
+
+from xdis import IS_PYPY, PYTHON_VERSION_TRIPLE
 
 
 def source_tempfile_remap(prefix, text, tempdir=None):
@@ -35,7 +38,7 @@ def source_tempfile_remap(prefix, text, tempdir=None):
 
 def deparse_fn(code):
     try:
-        if 3.7 <= PYTHON_VERSION <= 3.8:
+        if (3, 7) <= PYTHON_VERSION_TRIPLE <= (3, 8):
             from uncompyle6.semantics.linemap import (
                 deparse_code_with_fragments_and_map as deparse_code,
             )
@@ -46,12 +49,10 @@ def deparse_fn(code):
 
     except ImportError:
         return None
-    sys_version = sys.version[:5]
     try:
-        float_version = py_str2float(sys_version)
-        deparsed = deparse_code(float_version, code, is_pypy=IS_PYPY)
+        deparsed = deparse_code(PYTHON_VERSION_TRIPLE, code, is_pypy=IS_PYPY)
         return deparsed
-    except:
+    except Exception:
         raise
     return None
 
@@ -131,7 +132,7 @@ def get_onoff(errmsg, arg, default=None, print_error=True):
 def get_val(curframe, errmsg, arg):
     try:
         return eval(arg, curframe.f_globals, curframe.f_locals)
-    except:
+    except Exception:
         t, v = sys.exc_info()[:2]
         if isinstance(t, str):
             exc_type_name = t
@@ -197,7 +198,13 @@ def show_onoff(b):
 def run_show_val(obj, name):
     """Generic subcommand value display"""
     val = obj.debugger.settings[obj.name]
-    obj.msg("%s is %s." % (obj.name, obj.cmd.proc._saferepr(val),))
+    obj.msg(
+        "%s is %s."
+        % (
+            obj.name,
+            obj.cmd.proc._saferepr(val),
+        )
+    )
     return False
 
 
