@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2009-2010, 2013, 2015, 2017, 2020, 2023 Rocky
-#  Bernstein
+#  Copyright (C) 2009-2010, 2013, 2015, 2017, 2020, 2023-2024
+#  Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ class PythonCommand(DebuggerCommand):
 
     `ipython`, `bpython`"""
 
-    aliases = ("py", "shell")
+    aliases = ("py", "interact", "shell")
     short_help = "Run Python as a command subshell"
 
     DebuggerCommand.setup(locals(), category="data", max_args=1)
@@ -57,7 +57,7 @@ class PythonCommand(DebuggerCommand):
     def run(self, args):
         # See if python's code module is around
 
-        # Python does it's own history thing.
+        # Python does its own history thing.
         # Make sure it doesn't damage ours.
         intf = self.debugger.intf[-1]
         if isinstance(intf, ServerInterface):
@@ -141,7 +141,7 @@ Use dbgr(*string*) to issue debugger command: *string*"""
 # Monkey-patched from code.py
 # FIXME: get changes into Python.
 def interact(banner=None, readfunc=None, my_locals=None, my_globals=None):
-    """Almost a copy of code.interact
+    """Almost a copy of ``code.interact``.
     Closely emulate the interactive Python interpreter.
 
     This is a backwards compatible interface to the InteractiveConsole
