@@ -1,17 +1,15 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2015, 2017-2018, 2020 Rocky Bernstein
+#   Copyright (C) 2015, 2017-2018, 2020, 2024 Rocky Bernstein
 #
 
 from pygments.styles import STYLE_MAP
+from trepan.lib.complete import complete_token
+from trepan.processor.command.base_subcmd import DebuggerSubcommand
 
 style_names = sorted(list(STYLE_MAP.keys()))
 
-# Our local modules
-from trepan.processor.command import base_subcmd as Mbase_subcmd
-from trepan.lib import complete as Mcomplete
 
-
-class SetStyle(Mbase_subcmd.DebuggerSubcommand):
+class SetStyle(DebuggerSubcommand):
     """**set style** [*pygments-style*]
 
     Set the pygments style in to use in formatting text for a 256-color terminal.
@@ -34,7 +32,7 @@ class SetStyle(Mbase_subcmd.DebuggerSubcommand):
     `show style`, `set highlight`"""
 
     def complete(self, prefix):
-        return Mcomplete.complete_token(style_names, prefix)
+        return complete_token(style_names, prefix)
 
     in_list = True
     min_abbrev = len("sty")
@@ -42,15 +40,13 @@ class SetStyle(Mbase_subcmd.DebuggerSubcommand):
 
     def run(self, args):
         if len(args) == 0:
-            self.section("style names: ")
-            self.msg(self.columnize_commands(style_names))
-            return
+            return self.proc.commands["show"].cmds.subcmds["styles"].run([])
         if args[0] == "none":
             self.debugger.settings[self.name] = None
             return
 
         if args[0] not in style_names:
-            self.errmsg("style name '%s' not valid. valid names are: " % args[0])
+            self.errmsg(f"style name '{args[0]}' not valid. valid names are: ")
             self.msg(self.columnize_commands(style_names))
             return
 
@@ -60,10 +56,8 @@ class SetStyle(Mbase_subcmd.DebuggerSubcommand):
     pass
 
 
-# if __name__ == '__main__':
-#     from trepan.processor.command.set_subcmd import __demo_helper__ as Mhelper
-#     sub = Mhelper.demo_run(SetWidth)
-#     d = sub.proc.debugger
-#     sub.run(['emacs'])
-#     print(d.settings['emacs'])
-#     pass
+if __name__ == '__main__':
+    from trepan.processor.command.set_subcmd.__demo_helper__ import demo_run
+    demo_run(SetStyle, ["emacs"])
+    demo_run(SetStyle, [])
+    pass
